@@ -1,7 +1,7 @@
 package IOD::Examples;
 
-our $DATE = '2014-08-17'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2014-08-28'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 1;
 # ABSTRACT: Example .IOD configuration files
@@ -18,7 +18,7 @@ IOD::Examples - Example .IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.04 of IOD::Examples (from Perl distribution IOD-Examples), released on 2014-08-17.
+This document describes version 0.05 of IOD::Examples (from Perl distribution IOD-Examples), released on 2014-08-28.
 
 =head1 HOMEPAGE
 
@@ -26,7 +26,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/IOD-Exampl
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-IOD-Examples>.
+Source repository is at L<https://github.com/perlancar/perl-IOD-Examples>.
 
 =head1 BUGS
 
@@ -38,11 +38,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
